==> jasperserver-2.1.0-src.zip: jasperserver-2.1.0-src/jasperserver/jasperserver-ws/src/main/java/com/jaspersoft/jasperserver/ws/axis2/RepositoryServiceContext.java <==
/*
 * Copyright (C) 2006 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.ws.axis2;

import java.util.Map;

import org.apache.axis.attachments.AttachmentPart;

import com.jaspersoft.jasperserver.api.engine.common.service.EngineService;
import com.jaspersoft.jasperserver.api.metadata.common.domain.Resource;
import com.jaspersoft.jasperserver.api.metadata.common.service.RepositoryService;
import com.jaspersoft.jasperserver.api.metadata.xml.domain.impl.ResourceDescriptor;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: RepositoryServiceContext.java 9304 2007-08-02 16:59:49Z lucian $
 */
public interface RepositoryServiceContext {

	RepositoryService getRepository();
	
	EngineService getEngine();
	
	ResourceHandlerRegistry getHandlerRegistry();
	
	String getMessage(String messageCode, Object[] args);

	ResourceDescriptor createResourceDescriptor(String referenceURI) throws WSException;
	
	ResourceDescriptor createResourceDescriptor(Resource resource) throws WSException;

	ResourceDescriptor createResourceDescriptor(Resource resource, Map options) throws WSException;

	AttachmentPart[] getMessageAttachments();

	RepositoryHelper getRepositoryHelper();
	
}

==> jasperserver-3.5.0-src.zip: jasperserver-3.5.0-src/jasperserver/jasperserver-ws/src/main/java/com/jaspersoft/jasperserver/ws/axis2/RepositoryServiceContext.java <==
/*
 * Copyright (C) 2006 JasperSoft http://www.jaspersoft.com
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed WITHOUT ANY WARRANTY; and without the 
 * implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see http://www.gnu.org/licenses/gpl.txt 
 * or write to:
 * 
 * Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330,
 * Boston, MA  USA  02111-1307
 */

package com.jaspersoft.jasperserver.ws.axis2;

import java.util.Map;

import org.apache.axis.attachments.AttachmentPart;

import com.jaspersoft.jasperserver.api.engine.common.service.EngineService;
import com.jaspersoft.jasperserver.api.metadata.common.domain.Resource;
import com.jaspersoft.jasperserver.api.metadata.common.service.RepositoryService;
import com.jaspersoft.jasperserver.api.metadata.xml.domain.impl.ResourceDescriptor;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: RepositoryServiceContext.java 14653 2008-11-17 12:43:37Z lucian $
 */
public interface RepositoryServiceContext {

	RepositoryService getRepository();
	
	EngineService getEngine();
	
	ResourceHandlerRegistry getHandlerRegistry();
	
	String getMessage(String messageCode, Object[] args);

	ResourceDescriptor createResourceDescriptor(String referenceURI) throws WSException;
	
	ResourceDescriptor createResourceDescriptor(Resource resource) throws WSException;

	ResourceDescriptor createResourceDescriptor(Resource resource, Map options) throws WSException;

	AttachmentPart[] getMessageAttachments();

	RepositoryHelper getRepositoryHelper();
	
	/**
	 * Returns the service configuration object.
	 * 
	 * @return the service configuration object
	 */
	ManagementServiceConfiguration getServiceConfiguration();
	
}
